/****************************************************************************
 *                       BK PRECISION Programmable DC Power Supply                           
 *---------------------------------------------------------------------------
 *   Copyright (c) National Instruments 1998.  All Rights Reserved.         
 *---------------------------------------------------------------------------
 *                                                                          
 * Title:    XLN.h                                        
 * Purpose:  BK PRECISION Programmable DC Power Supply                                       
 *           instrument driver declarations.                                
 *                                                                          
 ****************************************************************************/

#ifndef __XLN_HEADER
#define __XLN_HEADER

#include <ivi.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/
#define XLN_MAJOR_VERSION                1     /* Instrument driver major version   */
#define XLN_MINOR_VERSION                0     /* Instrument driver minor version   */
                                                                
#define XLN_CLASS_SPEC_MAJOR_VERSION     2     /* Class specification major version */
#define XLN_CLASS_SPEC_MINOR_VERSION     0     /* Class specification minor version */



#define XLN_SUPPORTED_INSTRUMENT_MODELS  "XLN3640,XLN6024,XLN8018,XLN10014"
#define XLN_DRIVER_VENDOR                "BK PRECISION"
#define XLN_DRIVER_DESCRIPTION           "BK XLN3640/XLN6024/XLN8018/XLN10014 is a programmable DC power supply"
                    



/**************************************************************************** 
 *------------------------------ Useful Macros -----------------------------* 
 ****************************************************************************/

        /*===============================================================
           Add useful instrument macros here.                                                 
         *===========================================================*/

/**************************************************************************** 
 *---------------------------- Attribute Defines ---------------------------* 
 ****************************************************************************/

    /*- IVI Inherent Instrument Attributes ---------------------------------*/    

        /* User Options */
#define XLN_ATTR_RANGE_CHECK                   IVI_ATTR_RANGE_CHECK                    /* ViBoolean */
#define XLN_ATTR_QUERY_INSTR_STATUS            IVI_ATTR_QUERY_INSTR_STATUS             /* ViBoolean */
#define XLN_ATTR_CACHE                         IVI_ATTR_CACHE                          /* ViBoolean */
#define XLN_ATTR_SIMULATE                      IVI_ATTR_SIMULATE                       /* ViBoolean */
#define XLN_ATTR_RECORD_COERCIONS              IVI_ATTR_RECORD_COERCIONS               /* ViBoolean */

        /* Instrument Capabilities */
#define XLN_ATTR_NUM_CHANNELS                  IVI_ATTR_NUM_CHANNELS                   /* ViInt32,  read-only  */

        /* Driver Information  */
#define XLN_ATTR_SPECIFIC_DRIVER_PREFIX        IVI_ATTR_SPECIFIC_DRIVER_PREFIX         /* ViString, read-only  */
#define XLN_ATTR_SUPPORTED_INSTRUMENT_MODELS   IVI_ATTR_SUPPORTED_INSTRUMENT_MODELS    /* ViString, read-only  */
#define XLN_ATTR_GROUP_CAPABILITIES            IVI_ATTR_GROUP_CAPABILITIES             /* ViString, read-only  */
#define XLN_ATTR_INSTRUMENT_MANUFACTURER       IVI_ATTR_INSTRUMENT_MANUFACTURER        /* ViString, read-only  */
#define XLN_ATTR_INSTRUMENT_MODEL              IVI_ATTR_INSTRUMENT_MODEL               /* ViString, read-only  */
#define XLN_ATTR_INSTRUMENT_FIRMWARE_REVISION  IVI_ATTR_INSTRUMENT_FIRMWARE_REVISION              /* ViString, read-only  */
#define XLN_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION  /* ViInt32,  read-only  */
#define XLN_ATTR_SPECIFIC_DRIVER_MINOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_MINOR_VERSION  /* ViInt32,  read-only  */
#define XLN_ATTR_SPECIFIC_DRIVER_REVISION      IVI_ATTR_SPECIFIC_DRIVER_REVISION       /* ViString, read-only  */
#define XLN_ATTR_SPECIFIC_DRIVER_VENDOR        IVI_ATTR_SPECIFIC_DRIVER_VENDOR         /* ViString, read-only  */
#define XLN_ATTR_SPECIFIC_DRIVER_DESCRIPTION   IVI_ATTR_SPECIFIC_DRIVER_DESCRIPTION    /* ViString, read-only  */
#define XLN_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION /* ViInt32, read-only */
#define XLN_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION /* ViInt32, read-only */

        /* Error Info */
#define XLN_ATTR_PRIMARY_ERROR                 IVI_ATTR_PRIMARY_ERROR                  /* ViInt32   */
#define XLN_ATTR_SECONDARY_ERROR               IVI_ATTR_SECONDARY_ERROR                /* ViInt32   */
#define XLN_ATTR_ERROR_ELABORATION             IVI_ATTR_ERROR_ELABORATION              /* ViString  */

        /* Advanced Session Information */
#define XLN_ATTR_LOGICAL_NAME                  IVI_ATTR_LOGICAL_NAME                   /* ViString, read-only  */
#define XLN_ATTR_RESOURCE_DESCRIPTOR           IVI_ATTR_RESOURCE_DESCRIPTOR            /* ViString, read-only  */
#define XLN_ATTR_IO_SESSION_TYPE               IVI_ATTR_IO_SESSION_TYPE                /* ViString, read-only  */
#define XLN_ATTR_IO_SESSION                    IVI_ATTR_IO_SESSION                     /* ViSession, read-only */
    

    /*- Instrument-Specific Attributes -------------------------------------*/

#define XLN_ATTR_ID_QUERY_RESPONSE      (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1L)     /* ViString (Read Only) */
#define XLN_ATTR_ADDRESS_OF_MACHINE          (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 2L)
#define XLN_ATTR_BEEP_STATE                  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 3L)
#define XLN_ATTR_CURRENT_SETTING             (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 4L)
#define XLN_ATTR_CURRENT_OUTPUTTING          (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 5L)
#define XLN_ATTR_ISET                        (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 6L)
#define XLN_ATTR_KEY_LOCK                    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 7L)
#define XLN_ATTR_MODEL_NAME                  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 8L)
#define XLN_ATTR_OCP_STATE                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 9L)
#define XLN_ATTR_OCP_LEVEL                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 10L)
#define XLN_ATTR_OPP_STATE                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 11L)
#define XLN_ATTR_OPP_LEVEL                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 12L)
#define XLN_ATTR_OUTPUT_STATE                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 13L)
#define XLN_ATTR_OVP_STATE                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 14L)
#define XLN_ATTR_OVP_LEVEL                   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 15L)
#define XLN_ATTR_STATUS_VALUE                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 16L)
#define XLN_ATTR_VOLTAGE_VALUE               (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 17L)
#define XLN_ATTR_VOLTAGE_OUTPUTTING          (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 18L)
#define XLN_ATTR_VERSION_NUMBER              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 19L)
#define XLN_ATTR_VOLTAGE_SETTING             (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 20L)
#define XLN_ATTR_RECALL_SETTING              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 21L)
#define XLN_ATTR_SAVE_SETTING                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 22L)
#define XLN_ATTR_SELECT_MEMORY_NUMBER        (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 23L)
#define XLN_ATTR_VOLTAGE_STORED              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 24L)
#define XLN_ATTR_CURRENT_STORED              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 25L)
#define XLN_ATTR_VOLTAGE_LIMIT               (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 26L)
#define XLN_ATTR_CURRENT_LIMIT               (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 27L)
#define XLN_ATTR_CC_CV_MODE                  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 28L)
#define XLN_ATTR_SELECT_PROGRAM_NUMBER       (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 29L)
#define XLN_ATTR_CLEAR_PROGRAM_NUMBER        (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 30L)
#define XLN_ATTR_NEXT_PROGRAM_NUMBER         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 31L)
#define XLN_ATTR_PROGRAM_REPEAT              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 32L)
#define XLN_ATTR_PROGRAM_RUN_STATE           (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 33L)
#define XLN_ATTR_CC_CV_PROTECT_STATE         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 34L)
#define XLN_ATTR_CV_CC_PROTECT_STATE         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 35L)
#define XLN_ATTR_PARALLEL_OR_SERIES          (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 36L)
#define XLN_ATTR_MASTER_SLAVE_TYPE           (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 37L)
#define XLN_ATTR_EXTRA_5V_STATE              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 38L)
#define XLN_ATTR_EXTERNAL_TYPE               (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 39L)
#define XLN_ATTR_IP_CONFIGURE                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 40L)
#define XLN_ATTR_IP_ADDRESS                  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 41L)
#define XLN_ATTR_LCD_BACKLIGHT_STATE         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 42L)
#define XLN_ATTR_CURRENT_UNDER_BOOTING       (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 43L)
#define XLN_ATTR_OUTPUT_STATE_UNDER_BOOTING  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 44L)
#define XLN_ATTR_POWER_MODE_UNDER_BOOTING    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 45L)
#define XLN_ATTR_VOLTAGE_UNDER_BOOTING       (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 46L)
#define XLN_ATTR_REMOTE_INTERFACE            (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 47L)
#define XLN_ATTR_TIMER_STATE                 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 48L)
#define XLN_ATTR_TIMER_HOUR                  (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 49L)
#define XLN_ATTR_TIMER_MINUTE                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 50L)
#define XLN_ATTR_TIMER_SECOND                (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 51L)
#define XLN_ATTR_PROGRAM_STEP_CURRENT        (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 52L)
#define XLN_ATTR_PROGRAM_STEP_VOLTAGE        (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 53L)
#define XLN_ATTR_PROGRAM_STEP_ON_TIME        (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 54L)
#define XLN_ATTR_PROGRAM_STEP_OF_TOTAL       (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 55L)
#define XLN_ATTR_PROGRAM_STEP_NUMBER         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 56L)
#define XLN_ATTR_SELECT_PROGRAM_SAVE         (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 57L)
#define XLN_ATTR_VOLTAGE_SLEW_RATE           (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 58L)
#define XLN_ATTR_CURRENT_SLEW_RATE           (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 59L)
#define XLN_ATTR_CONNECTOR_DROP              (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 60L)
#define XLN_ATTR_EXTERNAL_INPUT_VOLTAGE      (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 61L)
#define XLN_ATTR_SERIES_NUMBER				 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 62L)      
#define XLN_ATTR_AVERAGE_TIMES				 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 63L) 

#define XLN_ATTR_CHAIN_ADDRESS_OF_MACHINE    (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 64L)
#define XLN_ATTR_CHAIN_RESPONSE_OF_MACHINE   (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 65L)
//#define XLN_ATTR_CHAIN_CLEAR_STATUS			 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 66L)	
//#define XLN_ATTR_CHAIN_RESET  				 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 67L)	
#define XLN_ATTR_CHAIN_QUERY_ID				 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 68L)	
#define XLN_ATTR_CHAIN_QUERY_VERSIOIN		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 69L)	
#define XLN_ATTR_CHAIN_QUERY_SERIES_NUMBER	 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 70L)	
#define XLN_ATTR_CHAIN_QUERY_STATUS			 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 71L)	
//#define XLN_ATTR_CHAIN_CLEAR_PROTECT		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 72L)	
#define XLN_ATTR_CHAIN_VOLTAGE_SETTING 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 73L) 	
#define XLN_ATTR_CHAIN_VOLTAGE_MEASURE 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 74L) 	      
#define XLN_ATTR_CHAIN_CURRENT_SETTING 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 75L) 	      
#define XLN_ATTR_CHAIN_CURRENT_MEASURE 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 76L) 	      
#define XLN_ATTR_CHAIN_VOUT_IOUT	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 77L) 	      
#define XLN_ATTR_CHAIN_OUTPUT_STATE 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 78L) 	      
#define XLN_ATTR_CHAIN_OVP_LEVEL	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 79L) 	      
#define XLN_ATTR_CHAIN_OVP_STATE	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 80L) 	      
#define XLN_ATTR_CHAIN_OCP_LEVEL	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 81L) 	      
#define XLN_ATTR_CHAIN_OCP_STATE	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 82L) 	      
#define XLN_ATTR_CHAIN_OPP_LEVEL	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 83L) 	      
#define XLN_ATTR_CHAIN_OPP_STATE	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 84L) 	      
#define XLN_ATTR_CHAIN_CVCC_MODE	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 85L) 	      
//#define XLN_ATTR_GLOBAL_RESET 		 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 86L) 	      
//#define XLN_ATTR_GLOBAL_CLEAR_STATUS 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 87L) 	      
//#define XLN_ATTR_GLOBAL_CLEAR_PROTECT 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 88L) 	      
#define XLN_ATTR_GLOBAL_VOLTAGE_SETTING		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 89L) 	      
#define XLN_ATTR_GLOBAL_CURRENT_SETTING		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 90L) 	      
#define XLN_ATTR_GLOBAL_OUTPUT_STATE 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 91L) 	      
#define XLN_ATTR_GLOBAL_OVP_LEVEL	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 92L) 	      
#define XLN_ATTR_GLOBAL_OVP_STATE	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 93L) 	      
#define XLN_ATTR_GLOBAL_OCP_LEVEL	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 94L) 	      
#define XLN_ATTR_GLOBAL_OCP_STATE	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 95L) 	      
#define XLN_ATTR_GLOBAL_OPP_LEVEL	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 96L) 	      
#define XLN_ATTR_GLOBAL_OPP_STATE	 		 (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 97L) 	      

    
/**************************************************************************** 
 *------------------------ Attribute Value Defines -------------------------* 
 ****************************************************************************/


/**************************************************************************** 
 *---------------- Instrument Driver Function Declarations -----------------* 
 ****************************************************************************/

    /*- Init and Close Functions -------------------------------------------*/
ViStatus _VI_FUNC  XLN_init (ViRsrc resourceName, ViBoolean IDQuery,
                                  ViBoolean resetDevice, ViSession *vi);
ViStatus _VI_FUNC  XLN_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                             ViBoolean resetDevice, ViString optionString, 
                                             ViSession *newVi);

ViStatus _VI_FUNC XLN_Set_Chain_Address (ViSession instrumentHandle,
                                         ViInt32 setChainAddress,
                                         ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_ClearChainStatus (ViSession instrumentHandle,
                                        ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_Chainreset (ViSession instrumentHandle,
                                  ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_ResetChainLatchedProtection (ViSession instrumentHandle,
                                                   ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_Set_Chain_VSET (ViSession instrumentHandle,
                                      ViReal64 setChainVSET,
                                      ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_Set_Chain_ISET (ViSession instrumentHandle,
                                      ViReal64 setChainISET,
                                      ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_SetChainOutputState (ViSession instrumentHandle,
                                           ViBoolean setChainOutputState,
                                           ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_SetChainOVPLevel (ViSession instrumentHandle,
                                        ViReal64 setChainOVPLevel,
                                        ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_Set_Chain_OVP_State (ViSession instrumentHandle,
                                           ViBoolean setChainOVPState,
                                           ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_SetChainOCPLevel (ViSession instrumentHandle,
                                        ViReal64 setChainOCPLevel,
                                        ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_Set_Chain_OCP_State (ViSession instrumentHandle,
                                           ViBoolean OCPChainState,
                                           ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_SetChainOPPLevel (ViSession instrumentHandle,
                                        ViReal64 setChainOPPLevel,
                                        ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_Set_Chain_OPP_State (ViSession instrumentHandle,
                                           ViBoolean OPPChainState,
                                           ViChar machineResponse[]);

ViStatus _VI_FUNC XLN_Globalreset (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_GlobalClearStatus (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_GlobalResetLatchedProtection (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_Global_Set_VSET (ViSession instrumentHandle,
                                       ViReal64 globalSetVSET);

ViStatus _VI_FUNC XLN_Global_Set_ISET (ViSession instrumentHandle,
                                       ViReal64 globalSetISET);

ViStatus _VI_FUNC XLN_GlobalSetOutputState (ViSession instrumentHandle,
                                            ViBoolean globalSetOutputState);

ViStatus _VI_FUNC XLN_GlobalSetOVPLevel (ViSession instrumentHandle,
                                         ViReal64 globalSetOVPLevel);

ViStatus _VI_FUNC XLN_Global_Set_OVP_State (ViSession instrumentHandle,
                                            ViBoolean global_SetOVPState);

ViStatus _VI_FUNC XLN_GlobalSetOCPLevel (ViSession instrumentHandle,
                                         ViReal64 globalSetOCPLevel);

ViStatus _VI_FUNC XLN_Global_Set_OCP_State (ViSession instrumentHandle,
                                            ViBoolean globalOCPState);

ViStatus _VI_FUNC XLN_GlobalSetOPPLevel (ViSession instrumentHandle,
                                         ViReal64 globalSetOPPLevel);

ViStatus _VI_FUNC XLN_Global_Set_OPP_State (ViSession instrumentHandle,
                                            ViBoolean globalOPPState);

ViStatus _VI_FUNC XLN_GetChainIDString (ViSession instrumentHandle,
                                        ViChar getChainIDString[]);

ViStatus _VI_FUNC XLN_GetChainVersionNumber (ViSession instrumentHandle,
                                             ViChar getChainVersionNumber[]);

ViStatus _VI_FUNC XLN_GetChainSeriesNumber (ViSession instrumentHandle,
                                            ViChar getChainSeriesNumber[]);

ViStatus _VI_FUNC XLN_GetChainStatusValue (ViSession instrumentHandle,
                                           ViInt32 *getChainStatusValue);

ViStatus _VI_FUNC XLN_Get_Chain_VSET (ViSession instrumentHandle,
                                      ViReal64 *getChainVSET);

ViStatus _VI_FUNC XLN_Get_Chain_Voltage_Outputting (ViSession instrumentHandle,
                                                    ViReal64 *getChainVoltageOutputting);

ViStatus _VI_FUNC XLN_Get_Chain_ISET (ViSession instrumentHandle,
                                      ViReal64 *getChainISET);

ViStatus _VI_FUNC XLN_Get_Chain_Current_Outputting (ViSession instrumentHandle,
                                                    ViReal64 *getChainCurrentOutputting);

ViStatus _VI_FUNC XLN_Get_Chain_Current_Voltage (ViSession instrumentHandle,
                                                 ViReal64 *getChainVlotageOutputting,
                                                 ViReal64 *getChainCurrentOutputting);

ViStatus _VI_FUNC XLN_GetChainOutputState (ViSession instrumentHandle,
                                           ViBoolean *getChainOutputState);

ViStatus _VI_FUNC XLN_GetChainOVPLevel (ViSession instrumentHandle,
                                        ViReal64 *getChainOVPLevel);

ViStatus _VI_FUNC XLN_GetChainOCPLevel (ViSession instrumentHandle,
                                        ViReal64 *getChainOCPLevel);

ViStatus _VI_FUNC XLN_Get_Chain_OCP_State (ViSession instrumentHandle,
                                           ViBoolean *getChainOCPState);

ViStatus _VI_FUNC XLN_GetChainOPPLevel (ViSession instrumentHandle,
                                        ViReal64 *getChainOPPLevel);

ViStatus _VI_FUNC XLN_Get_Chain_OVP_State (ViSession instrumentHandle,
                                           ViBoolean *getChainOVPState);

ViStatus _VI_FUNC XLN_Get_Chain_OPP_State (ViSession instrumentHandle,
                                           ViBoolean *getChainOPPState);

ViStatus _VI_FUNC XLN_GetChainOutputMode (ViSession instrumentHandle,
                                          ViChar getChainOutputMode[]);

ViStatus _VI_FUNC  XLN_close (ViSession vi);   

    /*- Coercion Info Functions --------------------------------------------*/
ViStatus _VI_FUNC  XLN_GetNextCoercionRecord (ViSession vi,
                                                   ViInt32 bufferSize,
                                                   ViChar record[]);

    /*- Locking Functions --------------------------------------------------*/
ViStatus _VI_FUNC  XLN_LockSession (ViSession vi, ViBoolean *callerHasLock);   
ViStatus _VI_FUNC  XLN_UnlockSession (ViSession vi, ViBoolean *callerHasLock);


    /*- Error Functions ----------------------------------------------------*/
ViStatus _VI_FUNC  XLN_error_query (ViSession vi, ViInt32 *errorCode,
                                         ViChar errorMessage[]);
ViStatus _VI_FUNC  XLN_GetErrorInfo (ViSession vi, ViStatus *primaryError, 
                                          ViStatus *secondaryError, 
                                          ViChar errorElaboration[256]);
ViStatus _VI_FUNC  XLN_ClearErrorInfo (ViSession vi);
ViStatus _VI_FUNC  XLN_error_message (ViSession vi, ViStatus errorCode,
                                           ViChar errorMessage[256]);

ViStatus _VI_FUNC XLN_GetsVIPRangeValue (ViSession instrumentHandle,
                                        ViReal64 *minCurrent,
                                        ViReal64 *maxCurrent,
                                        ViReal64 *minVoltage,
                                        ViReal64 *maxVoltage, ViReal64 *minOCP,
                                        ViReal64 *maxOCP, ViReal64 *minOVP,
                                        ViReal64 *maxOVP, ViReal64 *minOPP,
                                        ViReal64 *maxOPP,
                                        ViReal64 *minVoltageSlewRate,
                                        ViReal64 *maxVoltageSlewRate,
                                        ViReal64 *minCurrentSlewRate,
                                        ViReal64 *maxCurrentSlewRate);

    

ViStatus _VI_FUNC XLN_FetchCurrent (ViSession instrumentHandle,
                                   ViReal64 *fetchCurrent);

ViStatus _VI_FUNC XLN_FetchVoltage (ViSession instrumentHandle,
                                   ViReal64 *fetchVoltage);

ViStatus _VI_FUNC XLN_MeasureCurrent (ViSession instrumentHandle,
                                     ViReal64 *measureCurrent);

ViStatus _VI_FUNC XLN_MeasureVoltage (ViSession instrumentHandle,
                                     ViReal64 *measureVoltage);

    /*- Utility Functions --------------------------------------------------*/
ViStatus _VI_FUNC  XLN_reset (ViSession vi);
ViStatus _VI_FUNC  XLN_self_test (ViSession vi, ViInt16 *selfTestResult,
                                       ViChar selfTestMessage[]);
ViStatus _VI_FUNC  XLN_revision_query (ViSession vi, 
                                            ViChar instrumentDriverRevision[],
                                            ViChar firmwareRevision[]);
ViStatus _VI_FUNC  XLN_WriteInstrData (ViSession vi, ViConstString writeBuffer); 
ViStatus _VI_FUNC  XLN_ReadInstrData  (ViSession vi, ViInt32 numBytes, 
                                            ViChar rdBuf[], ViInt32 *bytesRead);

    /*- Set, Get, and Check Attribute Functions ----------------------------*/
ViStatus _VI_FUNC  XLN_GetAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 *value);
ViStatus _VI_FUNC  XLN_GetAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 *value);
ViStatus _VI_FUNC  XLN_GetAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 bufSize, ViChar value[]); 
ViStatus _VI_FUNC  XLN_GetAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession *value);
ViStatus _VI_FUNC  XLN_GetAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean *value);

ViStatus _VI_FUNC XLN_Set_Address (ViSession instrumentHandle, ViInt32 setAddress);

ViStatus _VI_FUNC XLN_SetExtra5VState (ViSession instrumentHandle,
                                      ViBoolean setExtra5VState);

ViStatus _VI_FUNC XLN_SetExternalType (ViSession instrumentHandle,
                                      ViInt32 setExternalType);

ViStatus _VI_FUNC XLN_SetIPParameters (ViSession instrumentHandle,
                                      ViBoolean IPConfigure, ViChar IPAddress[]);

ViStatus _VI_FUNC XLN_SetLCDBackLight (ViSession instrumentHandle,
                                       ViInt32 setLCDBackLight);

ViStatus _VI_FUNC XLN_SetCurrentUnderBooting (ViSession instrumentHandle,
                                             ViReal64 setCurrentUnderBooting);

ViStatus _VI_FUNC XLN_SetOutputStateUnderBooting (ViSession instrumentHandle,
                                                 ViBoolean setOutputStateUnderBooting);

ViStatus _VI_FUNC XLN_SetPowerModeUnderBooting (ViSession instrumentHandle,
                                               ViInt32 setPowerModeUnderBooting);

ViStatus _VI_FUNC XLN_SetVoltageUnderBooting (ViSession instrumentHandle,
                                             ViReal64 setVoltageUnderBooting);

ViStatus _VI_FUNC XLN_SetRemoteInterface (ViSession instrumentHandle,
                                         ViInt32 setRemoteInterface);

ViStatus _VI_FUNC XLN_SetFactoryDefault (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_Get_Average_Times (ViSession instrumentHandle,
                                         ViInt32 *getAverageTimes);

ViStatus _VI_FUNC XLN_Get_Beep (ViSession instrumentHandle, ViBoolean *getBeep);

ViStatus _VI_FUNC XLN_Set_Average_Times (ViSession instrumentHandle,
                                         ViInt32 setAverageTimes);

ViStatus _VI_FUNC XLN_Set_Beep (ViSession instrumentHandle, ViBoolean setBeep);

ViStatus _VI_FUNC XLN_Clear_Protect_Status (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_Set_Current (ViSession instrumentHandle,
                                  ViReal64 setCurrent);

ViStatus _VI_FUNC XLN_Set_ISET (ViSession instrumentHandle, ViReal64 setISET);

ViStatus _VI_FUNC XLN_SetIPConfigure (ViSession instrumentHandle,
                                     ViBoolean IPConfigure);

ViStatus _VI_FUNC XLN_SetStaticIPAddress (ViSession instrumentHandle,
                                         ViChar staticIPAddress[]);

ViStatus _VI_FUNC XLN_Set_KeyLock (ViSession instrumentHandle,
                                  ViBoolean setKeyLock);

ViStatus _VI_FUNC XLN_Set_OCP_State (ViSession instrumentHandle,
                                    ViBoolean OCPState);

ViStatus _VI_FUNC XLN_SetOCPLevel (ViSession instrumentHandle,
                                  ViReal64 setOCPLevel);

ViStatus _VI_FUNC XLN_Set_OPP_State (ViSession instrumentHandle,
                                    ViBoolean OPPState);

ViStatus _VI_FUNC XLN_SetOPPLevel (ViSession instrumentHandle,
                                  ViReal64 setOPPLevel);

ViStatus _VI_FUNC XLN_SetOutputState (ViSession instrumentHandle,
                                     ViBoolean setOutputState);

ViStatus _VI_FUNC XLN_Set_OVP_State (ViSession instrumentHandle,
                                    ViBoolean setOVPState);

ViStatus _VI_FUNC XLN_SetOVPLevel (ViSession instrumentHandle,
                                  ViReal64 setOVPLevel);

ViStatus _VI_FUNC XLN_SetVoltage (ViSession instrumentHandle, ViReal64 setVoltage);

ViStatus _VI_FUNC XLN_Set_VSET (ViSession instrumentHandle, ViReal64 setVSET);



ViStatus _VI_FUNC XLN_Get_Address (ViSession instrumentHandle,
                                  ViInt32 *getAddress);

ViStatus _VI_FUNC XLN_Get_Current (ViSession instrumentHandle,
                                  ViReal64 *getCurrent);

ViStatus _VI_FUNC XLN_Get_Current_Outputting (ViSession instrumentHandle,
                                             ViReal64 *getCurrentOutputting);

ViStatus _VI_FUNC XLN_Get_ISET (ViSession instrumentHandle, ViReal64 *getISET);

ViStatus _VI_FUNC XLN_Get_Model_Name (ViSession instrumentHandle,
                                     ViChar getModelName[]);

ViStatus _VI_FUNC XLN_Get_OCP_State (ViSession instrumentHandle,
                                    ViBoolean *OCPState);

ViStatus _VI_FUNC XLN_GetOCPLevel (ViSession instrumentHandle,
                                  ViReal64 *getOCPLevel);

ViStatus _VI_FUNC XLN_Get_OPP_State (ViSession instrumentHandle,
                                    ViBoolean *OPPState);

ViStatus _VI_FUNC XLN_GetOPPLevel (ViSession instrumentHandle,
                                  ViReal64 *getOPPLevel);

ViStatus _VI_FUNC XLN_Get_OVP_State (ViSession instrumentHandle,
                                    ViBoolean *getOVPState);

ViStatus _VI_FUNC XLN_GetOVPLevel (ViSession instrumentHandle,
                                  ViReal64 *getOVPLevel);

ViStatus _VI_FUNC XLN_GetStatusValue (ViSession instrumentHandle,
                                     ViInt32 *getStatusValue);

ViStatus _VI_FUNC XLN_GetVersionNumber (ViSession instrumentHandle,
                                       ViChar getVersionNumber[]);

ViStatus _VI_FUNC XLN_GetVoltage (ViSession instrumentHandle,
                                 ViReal64 *getVoltage);

ViStatus _VI_FUNC XLN_Get_Voltage_Outputting (ViSession instrumentHandle,
                                             ViReal64 *getVoltageOutputting);

ViStatus _VI_FUNC XLN_Get_VSET (ViSession instrumentHandle, ViReal64 *getVSET);

ViStatus _VI_FUNC XLN_ClearStatus (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_GetIDString (ViSession instrumentHandle,
                                  ViChar getIDString[]);

ViStatus _VI_FUNC XLN_SetRecallSetting (ViSession instrumentHandle,
                                       ViInt32 recallSetting);

ViStatus _VI_FUNC XLN_SaveSetting (ViSession instrumentHandle,
                                  ViInt32 saveSetting);

ViStatus _VI_FUNC XLN_AbortOutputAction (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_SelectMemoryNumber (ViSession instrumentHandle,
                                         ViInt32 selectMemoryNumber);

ViStatus _VI_FUNC XLN_SetVoltageStored (ViSession instrumentHandle,
                                       ViReal64 setVoltageStored);

ViStatus _VI_FUNC XLN_SetCurrentStored (ViSession instrumentHandle,
                                       ViReal64 setCurrentStored);

ViStatus _VI_FUNC XLN_SaveParameters_toMEM (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_GetSelectMemoryNumber (ViSession instrumentHandle,
                                            ViInt32 *getSelectMemoryNumber);

ViStatus _VI_FUNC XLN_GetVoltageStored (ViSession instrumentHandle,
                                       ViReal64 *getVoltageStored);

ViStatus _VI_FUNC XLN_GetCurrentStored (ViSession instrumentHandle,
                                       ViReal64 *getCurrentStored);

ViStatus _VI_FUNC XLN_SetConnectorDropState (ViSession instrumentHandle,
                                            ViBoolean setConnectorDropState);

ViStatus _VI_FUNC XLN_SetExternalInputVoltage (ViSession instrumentHandle,
                                              ViBoolean setExternalInputVoltage);

ViStatus _VI_FUNC XLN_SetVoltageLimit (ViSession instrumentHandle,
                                      ViReal64 setVoltageLimit);

ViStatus _VI_FUNC XLN_SetCurrentLimit (ViSession instrumentHandle,
                                      ViReal64 setCurrentLimit);

ViStatus _VI_FUNC XLN_SetVoltageSlewRate (ViSession instrumentHandle,
                                         ViReal64 setVoltageSlewRate);

ViStatus _VI_FUNC XLN_GetVoltageSlewRate (ViSession instrumentHandle,
                                         ViReal64 *getVoltageSlewRate);

ViStatus _VI_FUNC XLN_SetCurrentSlewRate (ViSession instrumentHandle,
                                         ViReal64 setCurrentSlewRate);

ViStatus _VI_FUNC XLN_ResetLatchedProtection (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_GetOutputState (ViSession instrumentHandle,
                                     ViBoolean *getOutputState);

ViStatus _VI_FUNC XLN_GetConnectorDropState (ViSession instrumentHandle,
                                            ViBoolean *getConnectorDropState);

ViStatus _VI_FUNC XLN_GetExternalInputVoltage (ViSession instrumentHandle,
                                              ViBoolean *getExternalInputVoltage);

ViStatus _VI_FUNC XLN_GetVoltageLimit (ViSession instrumentHandle,
                                      ViReal64 *getVoltageLimit);

ViStatus _VI_FUNC XLN_GetCurrentLimit (ViSession instrumentHandle,
                                      ViReal64 *getCurrentLimit);

ViStatus _VI_FUNC XLN_GetCurrentSlewRate (ViSession instrumentHandle,
                                         ViReal64 *getCurrentSlewRate);

ViStatus _VI_FUNC XLN_GetOutputMode (ViSession instrumentHandle,
                                    ViChar getOutputMode[]);

ViStatus _VI_FUNC XLN_SelectProgramNumber (ViSession instrumentHandle,
                                          ViInt32 selectProgramNumber);

ViStatus _VI_FUNC XLN_ClearProgramNumber (ViSession instrumentHandle,
                                         ViInt32 selectProgramNumber);

ViStatus _VI_FUNC XLN_ClearAllProgram (ViSession instrumentHandle);





ViStatus _VI_FUNC XLN_SetProgramRunState (ViSession instrumentHandle,
                                         ViInt32 selectProgramNumber,
                                         ViBoolean setProgramRunState);

ViStatus _VI_FUNC XLN_SaveProgram (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_SelectStepNumberofProgram (ViSession instrumentHandle,
                                                ViInt32 selectStepNumber_ofProgram);

ViStatus _VI_FUNC XLN_SetProgramParameters (ViSession instrumentHandle,
                                           ViInt32 selectProgramNumber,
                                           ViInt32 setProgramRepeat,
                                           ViInt32 setProgramStep_ofTotal,
                                           ViReal64 setCurrent_ofStep[],
                                           ViReal64 setVoltage_ofStep[],
                                           ViReal64 setOnTime_ofStep[],
                                           ViInt32 setNextProgramNumber);

ViStatus _VI_FUNC XLN_SetProgramNextRun (ViSession instrumentHandle,
                                        ViInt32 selectProgramNumber,
                                        ViInt32 setProgramRepeat,
                                        ViInt32 setNextProgramNumber);



ViStatus _VI_FUNC XLN_GetSelectProgramNumber (ViSession instrumentHandle,
                                             ViInt32 *getSelectProgramNumber);

ViStatus _VI_FUNC XLN_GetNextProgramNumber (ViSession instrumentHandle,
                                           ViInt32 *getNextProgramNumber);

ViStatus _VI_FUNC XLN_GetProgramRepeat (ViSession instrumentHandle,
                                       ViInt32 *getProgramRepeat);

ViStatus _VI_FUNC XLN_GetProgramTotal (ViSession instrumentHandle,
                                      ViInt32 *getProgramTotal);

ViStatus _VI_FUNC XLN_GetProgramRunState (ViSession instrumentHandle,
                                         ViBoolean *getProgramRunState);

ViStatus _VI_FUNC XLN_GetV_I_TSetsofStep (ViSession instrumentHandle,
                                         ViInt32 selectProgramNumber,
                                         ViInt32 selectStepNumber,
                                         ViReal64 *getCurrent_ofStep,
                                         ViReal64 *getVoltage_ofStep,
                                         ViReal64 *getOnTime_ofStep);



ViStatus _VI_FUNC XLN_SetCC_CVProtectState (ViSession instrumentHandle,
                                           ViBoolean setCC_CVProtectState);

ViStatus _VI_FUNC XLN_ResetLatchedProtect (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_SetCV_CCProtectState (ViSession instrumentHandle,
                                           ViBoolean setCV_CCProtectState);

ViStatus _VI_FUNC XLN_GetProtectState (ViSession instrumentHandle,
                                      ViBoolean *getProtectState);



ViStatus _VI_FUNC XLN_GetCC_CVProtectState (ViSession instrumentHandle,
                                           ViBoolean *getCC_CVProtectState);

ViStatus _VI_FUNC XLN_GetCV_CCProtectState (ViSession instrumentHandle,
                                           ViBoolean *getCV_CCProtectState);

ViStatus _VI_FUNC XLN_SetParallelorSeriesMode (ViSession instrumentHandle,
                                              ViInt32 setParallel_orSeriesMode,
                                              ViInt32 setMaster_Slave);



ViStatus _VI_FUNC XLN_GetParallelorSeriesMode (ViSession instrumentHandle,
                                              ViInt32 *getParallel_orSeriesMode,
                                              ViInt32 *getMaster_Slave);



ViStatus _VI_FUNC XLN_GetExtra5VState (ViSession instrumentHandle,
                                      ViBoolean *getExtra5VState);

ViStatus _VI_FUNC XLN_GetExternalType (ViSession instrumentHandle,
                                      ViInt32 *getExternalType);

ViStatus _VI_FUNC XLN_GetIPParameters (ViSession instrumentHandle,
                                      ViBoolean *IPConfigure, ViChar IPAddress[]);

ViStatus _VI_FUNC XLN_GetIPConfigure (ViSession instrumentHandle,
                                     ViBoolean *IPConfigure);

ViStatus _VI_FUNC XLN_GetIPAddress (ViSession instrumentHandle,
                                   ViChar IPAddress[]);

ViStatus _VI_FUNC XLN_Get_KeyLock (ViSession instrumentHandle,
                                  ViBoolean *getKeyLock);

ViStatus _VI_FUNC XLN_Get_LCD_Back_Light (ViSession instrumentHandle,
                                          ViInt32 *getLCDBackLight);

ViStatus _VI_FUNC XLN_GetCurrentUnderBooting (ViSession instrumentHandle,
                                             ViReal64 *getCurrentUnderBooting);

ViStatus _VI_FUNC XLN_GetOutputStateUnderBooting (ViSession instrumentHandle,
                                                 ViBoolean *getOutputStateUnderBooting);

ViStatus _VI_FUNC XLN_GetPowerModeUnderBooting (ViSession instrumentHandle,
                                               ViInt32 *getPowerModeUnderBooting);

ViStatus _VI_FUNC XLN_GetVoltageUnderBooting (ViSession instrumentHandle,
                                             ViReal64 *getVoltageUnderBooting);

//ViStatus _VI_FUNC XLN_GetFactoryDefault (ViSession instrumentHandle);

ViStatus _VI_FUNC XLN_GetRemoteInterface (ViSession instrumentHandle,
                                         ViInt32 *getRemoteInterface);

ViStatus _VI_FUNC XLN_GetSeriesNumber (ViSession instrumentHandle,
                                       ViChar getSeriesNumber[]);

ViStatus _VI_FUNC XLN_SetTimerState (ViSession instrumentHandle,
                                    ViBoolean setTimerState);



ViStatus _VI_FUNC XLN_SetTimerParameters (ViSession instrumentHandle,
                                         ViInt32 timerHour, ViInt32 timerMinute,
                                         ViInt32 timerSecond);

ViStatus _VI_FUNC XLN_GetTimerState (ViSession instrumentHandle,
                                    ViBoolean *getTimerState);

ViStatus _VI_FUNC XLN_GetTimerParameters (ViSession instrumentHandle,
                                         ViInt32 *timerHour,
                                         ViInt32 *timerMinute,
                                         ViInt32 *timerSecond);




ViStatus _VI_FUNC  XLN_SetAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 value);
ViStatus _VI_FUNC  XLN_SetAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 value);
ViStatus _VI_FUNC  XLN_SetAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViConstString value); 
ViStatus _VI_FUNC  XLN_SetAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession value);
ViStatus _VI_FUNC  XLN_SetAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean value);

ViStatus _VI_FUNC  XLN_CheckAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 value);
ViStatus _VI_FUNC  XLN_CheckAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 value);
ViStatus _VI_FUNC  XLN_CheckAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViConstString value); 
ViStatus _VI_FUNC  XLN_CheckAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession value);
ViStatus _VI_FUNC  XLN_CheckAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean value);

    /*********************************************************
        Functions reserved for class driver use only.
        End-users should not call these functions.  
     *********************************************************/
ViStatus _VI_FUNC  XLN_IviInit (ViRsrc resourceName, ViBoolean IDQuery, 
                                     ViBoolean reset, ViSession vi);
ViStatus _VI_FUNC  XLN_IviClose (ViSession vi);   

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define XLN_ERROR_NOT_SUPPORT_PARALLEL_SERIES_MODE  (IVI_SPECIFIC_ERROR_BASE + 1)
#define XLN_ERROR_0  0
#define XLN_ERROR_1  1
#define XLN_ERROR_2  2
#define XLN_ERROR_3  3
#define XLN_ERROR_4  4
#define XLN_ERROR_5  5
#define XLN_ERROR_6  6
#define XLN_ERROR_7  7
#define XLN_ERROR_8  8
#define XLN_ERROR_9  9
#define XLN_ERROR_10 10
#define XLN_ERROR_11 11
#define XLN_ERROR_12 12

/**************************************************************************** 
 *---------------------------- End Include File ----------------------------* 
 ****************************************************************************/
#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __XLN_HEADER */




